# Table of Contents

- [odata-integration-update](<./odata-integration-update.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [OData Integration Update: Translation Corrections (May 26, 2025)](<./OData-Integration-Update-Translation-Corrections-May-26-2025.md>)
  - [Background](<./OData-Integration-Update-Translation-Corrections-May-26-2025/Background.md>)
  - [Upcoming Changes](<./OData-Integration-Update-Translation-Corrections-May-26-2025/Upcoming-Changes.md>)
  - [Affected Fields](<./OData-Integration-Update-Translation-Corrections-May-26-2025/Affected-Fields.md>)
  - [Was this page helpful?](<./OData-Integration-Update-Translation-Corrections-May-26-2025/Was-this-page-helpful.md>)
